Evaluate endpoint criterion based on number of subjects with events.
Source:R/crit_endpoint.R
crit_ep_nsubev_01.RdThis function checks if the number of subjects with events in at least one study arm is greater than or equal to a specified minimum.
Arguments
- dat
data.table. The analysis data set.
- event_index
vector of integers that index the rows in
datthat match the definition of an 'event'. Matching is done via theINDEX_column indat.- subjectid_var
character. Name of the subject identifier variable in
dat(default is "USUBJID").- treatment_var
The name of the variable in dat containing the treatment group assignments.
- n_subj_event_min
The minimum number of subjects with events required in at least one study arm.
- ...
Additional arguments passed to the function.
Examples
dat <- data.table::data.table(
USUBJID = c("S1", "S2", "S3", "S4"),
TRT = c("Active", "Active", "Placebo", "Placebo")
)
dat[, INDEX_ := .I]
#> USUBJID TRT INDEX_
#> <char> <char> <int>
#> 1: S1 Active 1
#> 2: S2 Active 2
#> 3: S3 Placebo 3
#> 4: S4 Placebo 4
data.table::setkey(dat, INDEX_)
# Returns TRUE: Active arm has 2 subjects with events >= minimum of 2
crit_ep_nsubev_01(dat, event_index = c(1L, 2L),
subjectid_var = "USUBJID",
treatment_var = "TRT", n_subj_event_min = 2L)
#> [1] TRUE